==> spip_3.0.20.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_it_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=it_fem
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Indirizzo del sito', # MODIF
	'form_pet_aucune_signature' => 'Nessuna adesione corrisponde a questo codice...', # MODIF
	'form_pet_confirmation' => 'Conferma l’adesione:',
	'form_pet_deja_signe' => 'Hai già firmato questo testo.',
	'form_pet_envoi_mail_confirmation' => 'Ti è stato appena inviato un messaggio di posta elettronica. Dovrai visitare l’indirizzo web che appare nel messaggio per confermare la tua adesione.', # MODIF
	'form_pet_mail_confirmation' => 'Salve,

Hai richiesto di firmare la petizione:
@titre@.

Hai fornito le seguenti informazioni:
    Nome: @nom_email@
    Sito: @nom_site@ - @url_site@
    @message@

IMPORTANTE...

Per confermare la tua adesione è sufficiente visitare l’indirizzo web qui sotto (se non lo fai, la tua domanda sarà respinta):

    @url@


Grazie per la partecipazione',
	'form_pet_message_commentaire' => 'Un messaggio, un commento?', # MODIF
	'form_pet_nom_site2' => 'Nome del tuo sito Web', # MODIF
	'form_pet_probleme_liens' => 'Per favore, riprenda il suo messaggio ed elimini i link ipertestuali.',
	'form_pet_probleme_technique' => 'Le adesioni sono temporaneamente sospese per il verificarsi di problemi tecnici.',
	'form_pet_signature_validee' => 'La tua adesione è stata confermata. Grazie!',
	'form_pet_site_deja_enregistre' => 'Questo sito è già registrato',
	'form_pet_url_invalide' => 'L’URL indicato non risulta valido.',
	'form_pet_votre_email' => 'Il tuo indirizzo email',
	'form_pet_votre_nom' => 'Nome o pseudonimo', # MODIF
	'form_pet_votre_site' => 'Se hai un sito Web, puoi segnalarlo qui sotto',

	// I
	'info_adresse_email' => 'INDIRIZZO EMAIL:',
	'info_signature_supprimee' => 'Firma eliminata',
	'info_signature_supprimee_erreur' => 'Errore: questo codice di eliminazione non corrisponde a nessuna firma', # MODIF
	'info_site_web' => 'SITO WEB:',

	// L
	'lien_reponse_article' => 'Risposta all’articolo'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_it_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=it_fem
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Attiva la petizione',
	'bouton_radio_pas_petition' => 'Nessuna petizione',
	'bouton_radio_petition_activee' => 'Petizione attivata',
	'bouton_radio_supprimer_petition' => 'Elimina la petizione',

	// F
	'form_pet_adresse_site' => 'Indirizzo del sito', # MODIF
	'form_pet_aucune_signature' => 'Nessuna adesione corrisponde a questo codice...', # MODIF
	'form_pet_confirmation' => 'Conferma l’adesione:',
	'form_pet_deja_signe' => 'Hai già firmato questo testo.',
	'form_pet_envoi_mail_confirmation' => 'Ti è stato appena inviato un messaggio di posta elettronica. Dovrai visitare l’indirizzo web che appare nel messaggio per confermare la tua adesione.', # MODIF
	'form_pet_mail_confirmation' => 'Salve,

Hai richiesto di firmare la petizione:
@titre@.

Hai fornito le seguenti informazioni:
    Nome: @nom_email@
    Sito: @nom_site@ - @url_site@
    @message@

IMPORTANTE...

Per confermare la tua adesione è sufficiente visitare l’indirizzo web qui sotto (se non lo fai, la tua domanda sarà respinta):

    @url@


Grazie per la partecipazione',
	'form_pet_message_commentaire' => 'Un messaggio, un commento?', # MODIF
	'form_pet_nom_site2' => 'Nome del tuo sito Web', # MODIF
	'form_pet_probleme_liens' => 'Per favore, riprenda il suo messaggio ed elimini i link ipertestuali.',
	'form_pet_probleme_technique' => 'Le adesioni sono temporaneamente sospese per il verificarsi di problemi tecnici.',
	'form_pet_signature_validee' => 'La tua adesione è stata confermata. Grazie!',
	'form_pet_site_deja_enregistre' => 'Questo sito è già registrato',
	'form_pet_url_invalide' => 'L’URL indicato non risulta valido.',
	'form_pet_votre_email' => 'Il tuo indirizzo email',
	'form_pet_votre_nom' => 'Nome o pseudonimo', # MODIF
	'form_pet_votre_site' => 'Se hai un sito Web, puoi segnalarlo qui sotto',

	// I
	'info_adresse_email' => 'INDIRIZZO EMAIL:',
	'info_signature_supprimee' => 'Firma eliminata',
	'info_signature_supprimee_erreur' => 'Errore: questo codice di eliminazione non corrisponde a nessuna firma', # MODIF
	'info_site_web' => 'SITO WEB:',

	// L
	'lien_reponse_article' => 'Risposta all’articolo'
);

?>
